@@ -1,3 +1,18 @@
+/*
+  This is a forked version of the qrduino project.  The original is at
+  "https://github.com/tz1/qrduino". The author of this code is Tom
+  Zerucha, https://github.com/tz1.
+  
+  This file is licenced under the GNU General Public Licence, version 3.
+
+  This file, "qrencode.c", contains all of the C code of the qrduino
+  project in one file, except for the jpeg code which I don't need
+  since I output to PNG.
+
+  This comment was added by Ben Bullock <benkasminbullock@gmail.com>,
+  on 2015-09-05.
+*/
+
 #include <assert.h>
 #include <stdio.h>
 #include <string.h>
